

scope
==================================
*scope* is a Python package for simulating ground-based, high-resolution, cross-correlation spectroscopy
of exoplanet atmospheres (HRCCS). The goal of this package is to provide a simple way to
simulate HRCCS observations with a simple API.

*scope* is currently under development `on GitHub <https://github.com/arjunsavel/scope>`_ and is ready for beta users. The package currently supports
simulating transmission and emission spectra.





.. toctree::
   :maxdepth: 1
   :caption: Getting Started

   pages/installation
   pages/quickstart



.. toctree::
   :maxdepth: 1
   :caption: For developers

   pages/integrations
   pages/versioning


.. toctree::
   :maxdepth: 1
   :caption: Documentation

   pages/faq
   pages/api

License & attribution
---------------------

Copyright 2023 Arjun Savel.

The source code is made available under the terms of the MIT license.

If you make use of this package, please be sure to reference this repository in your work.
The associated paper (Savel et al. 2023b, in prep.) will be the preferred citation in
the future.
